@@ -17,4 +17,4 @@ if __name__ == '__main__':
     if __file__ != sys.argv[-1]:
         run(sys.argv[-1])
     else:
-        run('simulation_config.json')
+        run('${CONFIG}')
